@@ -19,7 +19,7 @@ class loadClassifierDataset(data.Dataset):
         else:
             tokenizer = AutoTokenizer.from_pretrained(pretrained)
 
-        cache_path = fpath + ".cache"
+        cache_path = fpath + "_maxlen" + str(maxlen) + "_" + pretrained.replace("/", "_") + ".cache"
         if os.path.isfile(cache_path) and cache:
             with open(cache_path, "rb") as cf:
                 outdata = pickle.load(cf)
