@@ -11,7 +11,7 @@ class TestEval(unittest.TestCase):
 
     def testEvalOnGen(self):
         result = os.system(
-            'tfkit-eval --model ./cache/10.pt --valid ../demo_data/generate.csv --metric emf1 --print')
+            'tfkit-eval --model ./cache/10.pt --valid ../demo_data/generate.csv --metric classification --print')
         print(result)
         result = os.system(
             'tfkit-eval --model ./cache/10.pt --valid ../demo_data/generate.csv --metric emf1 --print --beamsearch --outfile')
